==> custom-toolbox_25.08.3.tar.xz: BUILD/translations/custom-toolbox_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Custom Toolbox</source>
        <translation>Mukautettu työkalulaatikko</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Tietoja tästä sovelluksesta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Mukauta käynnistysohjelmaa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Sulje sovellus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Tämä on mukautettu käynnistysohjelma</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Näytä tämä ikkuna käynnistyksen yhteydessä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>etsi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Execution Error</source>
        <translation>Suoritusvirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>Failed to execute command: %1</source>
        <translation>Komentoa ei voitu suorittaa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Failed to start program: %1</source>
        <translation>Ohjelmaa ei voitu suorittaa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>Open List File</source>
        <translation>Avaa luettelotiedosto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>List Files (*.list)</source>
        <translation>Listaa tiedostot (*.list)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>File Selection Error</source>
        <translation>Tiedoston valintavirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>No file selected. Application will now exit.</source>
        <translation>Ei valittua tiedostoa. Sovellus suljetaan.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>File Open Error</source>
        <translation>Tiedoston avaamisvirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="306"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>Tiedostoa ei voitu avata. Haluatko yrittää uudelleen?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>File Not Found</source>
        <translation>Tiedostoa ei löytynyt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>The file %1 does not exist.</source>
        <translation>Tiedostoa %1 ei ole olemassa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <source>Could not open file: </source>
        <translation>Tiedostoa ei voitu avata:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="660"/>
        <source>Version:</source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="663"/>
        <source>About %1</source>
        <translation>%1 lisätietoja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Custom Toolbox on työkalu, jota käytetään mukautetun käynnistysohjelman luomiseen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="664"/>
        <source>%1 License</source>
        <translation>%1 lupa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="671"/>
        <source>%1 Help</source>
        <translation>%1 Apuopas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>Could not write file: %1</source>
        <translation>Tiedostoa ei voitu kirjoittaa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>File Removal Error</source>
        <translation>Tiedoston poistovirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>Could not remove file: %1</source>
        <translation>Tiedostoa ei voitu poistaa: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Tätä sovellusta voidaan käyttää mukautettujen käynnistimien luomiseen: painike-/kuvakelaatikko</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Älä näytä &quot;näytä tämä valintaikkuna käynnistettäessä&quot; -valintaruutua</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Sen .list-tiedoston koko polku ja nimi, jonka haluat ladata sovelluksen määrittämistä varten</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Olet kirjautunut sisään pääkäyttäjänä. Kirjaudu sisään normaalina käyttäjänä käyttääksesi tätä ohjelmaa.</translation>
    </message>
</context>
</TS>

==> custom-toolbox_25.11.tar.xz: BUILD/translations/custom-toolbox_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="20"/>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Custom Toolbox</source>
        <translation>Mukautettu työkalulaatikko</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="63"/>
        <source>About this application</source>
        <translation>Tietoja tästä sovelluksesta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="66"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="73"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="89"/>
        <source>Customize launcher</source>
        <translation>Mukauta käynnistysohjelmaa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="92"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="99"/>
        <source>Alt+E</source>
        <translation>Alt+E</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="163"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="170"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="183"/>
        <source>Close application</source>
        <translation>Sulje sovellus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="186"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="193"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="308"/>
        <source>This is a custom launcher</source>
        <translation>Tämä on mukautettu käynnistysohjelma</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <source>Show this dialog at start up</source>
        <translation>Näytä tämä ikkuna käynnistyksen yhteydessä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="346"/>
        <source>search</source>
        <translation>etsi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Execution Error</source>
        <translation>Suoritusvirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>Failed to execute command: %1</source>
        <translation>Komentoa ei voitu suorittaa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Failed to start program: %1</source>
        <translation>Ohjelmaa ei voitu suorittaa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>Open List File</source>
        <translation>Avaa luettelotiedosto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="297"/>
        <source>List Files (*.list)</source>
        <translation>Listaa tiedostot (*.list)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>File Selection Error</source>
        <translation>Tiedoston valintavirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="299"/>
        <source>No file selected. Application will now exit.</source>
        <translation>Ei valittua tiedostoa. Sovellus suljetaan.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>File Open Error</source>
        <translation>Tiedoston avaamisvirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="306"/>
        <source>Could not open file. Do you want to try again?</source>
        <translation>Tiedostoa ei voitu avata. Haluatko yrittää uudelleen?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>File Not Found</source>
        <translation>Tiedostoa ei löytynyt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>The file %1 does not exist.</source>
        <translation>Tiedostoa %1 ei ole olemassa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="569"/>
        <source>Could not open file: </source>
        <translation>Tiedostoa ei voitu avata:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="660"/>
        <source>Version:</source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="663"/>
        <source>About %1</source>
        <translation>%1 lisätietoja</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Custom Toolbox is a tool used for creating a custom launcher</source>
        <translation>Custom Toolbox on työkalu, jota käytetään mukautetun käynnistysohjelman luomiseen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="664"/>
        <source>%1 License</source>
        <translation>%1 lupa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="671"/>
        <source>%1 Help</source>
        <translation>%1 Apuopas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="722"/>
        <source>Could not write file: %1</source>
        <translation>Tiedostoa ei voitu kirjoittaa: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>File Removal Error</source>
        <translation>Tiedoston poistovirhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="726"/>
        <source>Could not remove file: %1</source>
        <translation>Tiedostoa ei voitu poistaa: %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>This app can be used to create custom launchers: box of buttons/icons</source>
        <translation>Tätä sovellusta voidaan käyttää mukautettujen käynnistimien luomiseen: painike-/kuvakelaatikko</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>Don&apos;t show &apos;show this dialog at startup&apos; checkbox</source>
        <translation>Älä näytä &quot;näytä tämä valintaikkuna käynnistettäessä&quot; -valintaruutua</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="85"/>
        <source>Full path and name of the .list file you want to load to set up the application</source>
        <translation>Sen .list-tiedoston koko polku ja nimi, jonka haluat ladata sovelluksen määrittämistä varten</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="95"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Olet kirjautunut sisään pääkäyttäjänä. Kirjaudu sisään normaalina käyttäjänä käyttääksesi tätä ohjelmaa.</translation>
    </message>
</context>
</TS>
